.. _MABWiser API:

MABWiser Public API
===================

base\_mab
---------

.. automodule:: mabwiser.base_mab
    :members:
    :undoc-members:
    :show-inheritance:

mab
---

.. automodule:: mabwiser.mab
    :members:
    :undoc-members:
    :show-inheritance:

simulator
---------

.. automodule:: mabwiser.simulator
    :members:
    :undoc-members:
    :show-inheritance:

utils
-----

.. automodule:: mabwiser.utils
    :members:
    :undoc-members:
    :show-inheritance:
